@@ -22,7 +22,7 @@ from sqlalchemy.sql import Select
 
 from fastapi_users_db_sqlalchemy.guid import GUID
 
-__version__ = "2.0.4"
+__version__ = "3.0.0"
 
 
 class SQLAlchemyBaseUserTable:
@@ -32,7 +32,7 @@ class SQLAlchemyBaseUserTable:
 
     id = Column(GUID, primary_key=True)
     email = Column(String(length=320), unique=True, index=True, nullable=False)
-    hashed_password = Column(String(length=72), nullable=False)
+    hashed_password = Column(String(length=1024), nullable=False)
     is_active = Column(Boolean, default=True, nullable=False)
     is_superuser = Column(Boolean, default=False, nullable=False)
     is_verified = Column(Boolean, default=False, nullable=False)
@@ -114,7 +114,7 @@ class SQLAlchemyUserDatabase(BaseUserDatabase[UD]):
                 self.session.add(oauth_account_table)
 
         await self.session.commit()
-        return user
+        return await self.get(user.id)
 
     async def update(self, user: UD) -> UD:
         user_table = await self.session.get(self.user_table, user.id)
@@ -133,7 +133,7 @@ class SQLAlchemyUserDatabase(BaseUserDatabase[UD]):
 
         await self.session.commit()
 
-        return user
+        return await self.get(user.id)
 
     async def delete(self, user: UD) -> None:
         statement = delete(self.user_table, self.user_table.id == user.id)
